Neko 1.99.7
A portable framework for high-order spectral element flow simulations
Loading...
Searching...
No Matches
opr_convect_scalar.cu File Reference
#include <string.h>
#include <stdlib.h>
#include <stdio.h>
#include "convect_scalar_kernel.h"
#include "elem_block_tune.h"
#include <device/device_config.h>
#include <device/cuda/check.h>
#include <common/neko_log.h>

Go to the source code of this file.

Macros

#define CASE_1D(LX, C)
 
#define CASE_1D_SEL(LX, SEL)
 
#define CASE_KSTEP(LX, C)
 
#define CASE_KSTEP_SEL(LX, SEL)
 
#define CASE(LX)
 
#define CASE_LARGE(LX)
 

Functions

template<const int >
int tune_convect_scalar (void *du, void *u, void *cr, void *cs, void *ct, void *dx, void *dy, void *dz, int *nel, int *lx, int *eb_sel, int *ch_sel)
 
void cuda_convect_scalar (void *du, void *u, void *cr, void *cs, void *ct, void *dx, void *dy, void *dz, int *nel, int *lx)
 

Macro Definition Documentation

◆ CASE

#define CASE (   LX)
Value:
case LX: \
if(autotune[LX] == 0 ) { \
cr, cs, ct, \
dx, dy, dz, \
nel, lx, &autotune_eb[LX], \
} else if (autotune[LX] == 1 ) { \
} else if (autotune[LX] == 2 ) { \
} \
break
__global__ void ale_add_kinematics_kernel(const int n, T *__restrict__ wx, T *__restrict__ wy, T *__restrict__ wz, const T *__restrict__ x_ref, const T *__restrict__ y_ref, const T *__restrict__ z_ref, const T *__restrict__ phi, const T *__restrict__ x, const T *__restrict__ y, const T *__restrict__ z, const kinematics_params_t kin_params)
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ u
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dx
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dz
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dy
__global__ void const T *__restrict__ const T *__restrict__ cr
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ cs
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ ct

◆ CASE_1D

#define CASE_1D (   LX,
  C 
)
Value:
<<<nblcks, NEKO_CHUNKS_NTHRDS(LX, C), 0, stream>>> \
((real *) du, (real *) u, \
(real *) cr, (real *) cs, (real *) ct, \
(real *) dx, (real *) dy, (real *) dz); \
__global__ void convect_scalar_kernel_1d(T *__restrict__ du, const T *__restrict__ u, const T *__restrict__ cr, const T *__restrict__ cs, const T *__restrict__ ct, const T *__restrict__ dx, const T *__restrict__ dy, const T *__restrict__ dz)
#define NEKO_CHUNKS(LX, C)
Definition elem_block.h:145
#define NEKO_CHUNKS_NTHRDS(LX, C)
Definition elem_block.h:146
double real

◆ CASE_1D_SEL

#define CASE_1D_SEL (   LX,
  SEL 
)
Value:
switch (SEL) { \
case 0: CASE_1D(LX, 0); break; \
case 1: CASE_1D(LX, 1); break; \
case 2: CASE_1D(LX, 2); break; \
default: CASE_1D(LX, 3); break; \
}
#define CASE_1D(LX, C)

◆ CASE_KSTEP

#define CASE_KSTEP (   LX,
  C 
)
Value:
<<<NEKO_EB_NBLCKS(*nel, LX, C), NEKO_EB_NTHRDS(LX, C), 0, stream>>> \
((real *) du, (real *) u, \
(real *) cr, (real *) cs, (real *) ct, \
(real *) dx, (real *) dy, (real *) dz, *nel); \
#define NEKO_EB(LX, C)
Definition elem_block.h:104
#define NEKO_EB_NBLCKS(NELV, LX, C)
Definition elem_block.h:106
#define NEKO_EB_NTHRDS(LX, C)
Definition elem_block.h:105

◆ CASE_KSTEP_SEL

#define CASE_KSTEP_SEL (   LX,
  SEL 
)
Value:
switch (SEL) { \
case 0: CASE_KSTEP(LX, 0); break; \
case 1: CASE_KSTEP(LX, 1); break; \
default: CASE_KSTEP(LX, 2); break; \
}
#define CASE_KSTEP(LX, C)

◆ CASE_LARGE

#define CASE_LARGE (   LX)
Value:
case LX: \
break

Function Documentation

◆ cuda_convect_scalar()

void cuda_convect_scalar ( void du,
void u,
void cr,
void cs,
void ct,
void dx,
void dy,
void dz,
int nel,
int lx 
)

Fortran wrapper for device cuda convective terms

Definition at line 58 of file opr_convect_scalar.cu.

Here is the call graph for this function:
Here is the caller graph for this function:

◆ tune_convect_scalar()

template<const int >
int tune_convect_scalar ( void du,
void u,
void cr,
void cs,
void ct,
void dx,
void dy,
void dz,
int nel,
int lx,
int eb_sel,
int ch_sel 
)

Definition at line 165 of file opr_convect_scalar.cu.

Here is the call graph for this function: